job "frontend" {
  datacenters = ["neptune"]
  type = "service"
  priority = 90

  group "tricot" {
    constraint {
      attribute = "${attr.unique.hostname}"
      value = "caribou"
    }

    network {
      port "http_port" { static = 80 }
      port "https_port" { static = 443 }
    }

    task "server" {
      driver = "docker"

      config {
        image = "lxpz/amd64_tricot:41"
        network_mode = "host"
        readonly_rootfs = true
        ports = [ "http_port", "https_port" ]
        volumes = [
          "secrets:/etc/tricot",
        ]
      }

      resources {
        cpu = 2000
        memory = 200
      }

      restart {
        interval = "30m"
        attempts = 2
        delay    = "15s"
        mode     = "delay"
      }

      template {
        data = "{{ key \"secrets/consul/consul-ca.crt\" }}"
        destination = "secrets/consul-ca.crt"
      }

      template {
        data = "{{ key \"secrets/consul/consul-client.crt\" }}"
        destination = "secrets/consul-client.crt"
      }

      template {
        data = "{{ key \"secrets/consul/consul-client.key\" }}"
        destination = "secrets/consul-client.key"
      }

      template {
        data = <<EOH
TRICOT_NODE_NAME={{ env "attr.unique.consul.name" }}
TRICOT_LETSENCRYPT_EMAIL=alex@adnab.me
TRICOT_ENABLE_COMPRESSION=true
TRICOT_CONSUL_HOST=https://localhost:8501
TRICOT_CONSUL_CA_CERT=/etc/tricot/consul-ca.crt
TRICOT_CONSUL_CLIENT_CERT=/etc/tricot/consul-client.crt
TRICOT_CONSUL_CLIENT_KEY=/etc/tricot/consul-client.key
TRICOT_HTTP_BIND_ADDR=[::]:80
TRICOT_HTTPS_BIND_ADDR=[::]:443
RUST_LOG=tricot=debug
EOH
        destination = "secrets/env"
        env = true
      }

      service {
        name = "tricot-http"
        port = "http_port"
        /* tags = [ "(diplonat (tcp_port 80))" ] */
        address_mode = "host"
      }

      service {
        name = "tricot-https"
        port = "https_port"
        /* tags = [ "(diplonat (tcp_port 443))" ] */
        address_mode = "host"
      }
    }
  }
}
